module.exports = function (config) {
  var path = require('path')
  var utils = require('./utils')

  return {
    entry: {
      app: './src/app.js'
    },
    output: {
      path: config.build.assetsRoot,
      publicPath: config.build.assetsPublicPath,
      filename: '[name].js'
    },
    resolve: {
      extensions: ['', '.js', '.vue'],
      fallback: [path.join(config.projectRoot, 'node_modules')],
      alias: {
        'src': path.resolve(config.projectRoot, 'src'),
        'assets': path.resolve(config.projectRoot, 'src/assets'),
        'components': path.resolve(config.projectRoot, 'src/components')
      }
    },
    resolveLoader: {
      fallback: [path.join(config.projectRoot, 'node_modules')]
    },
    module: {
      preLoaders: [
        {
          test: /\.vue$/,
          loader: 'eslint',
          include: config.projectRoot,
          exclude: /node_modules/
        },
        {
          test: /\.js$/,
          loader: 'eslint',
          include: config.projectRoot,
          exclude: /node_modules/
        }
      ],
      loaders: [
        {
          test: /\.vue$/,
          loader: 'vue'
        },
        {
          test: /\.js$/,
          loader: 'babel',
          include: config.jsInclude
        },
        {
          test: /\.json$/,
          loader: 'json'
        },
        {
          test: /\.html$/,
          loader: 'vue-html'
        },
        {
          test: /\.(png|jpe?g|gif|svg|woff2?|eot|ttf|otf)(\?.*)?$/,
          loader: 'url',
          query: {
            limit: 10000,
            name: utils.assetsPath(config, '[name].[hash:7].[ext]')
          }
        }
      ]
    },
    eslint: {
      formatter: require('eslint-friendly-formatter')
    },
    vue: {
      loaders: utils.cssLoaders()
    }
  }
}
